@@ -56,9 +56,9 @@ class CalculationDynamicFieldSerializer(GeneratorSerializer):
         calc = self.context.get("calculation")
         if calc:
             calc = get_operations(calc)
-            for name, value in ret.items():
-                if name in calc:
-                    data = replacer(calc[name], ret)
-                    ret[fname] = calculate(data)
+            for name, calc_value in calc.items():
+                if name in ret:
+                    data = replacer(calc_value, name, ret[name])
+                    ret[name] = calculate(data)
 
         return ret
