@@ -4,6 +4,7 @@ import csv
 import boto3
 import requests
 import hashlib
+from datetime import datetime, timedelta
 from io import StringIO, BytesIO
 from boto3.s3.transfer import TransferConfig
 from Crypto.Cipher import AES
@@ -385,3 +386,27 @@ def decrypt_data(data: dict, token: str, salt: Optional[str] = None) -> dict:
         return json.loads(data)
     except:
         raise ValueError('invalid secure params')
+
+
+def dates_chunker(
+    date_from: datetime, date_to: datetime, default_delta: int = 4
+) -> Generator:
+    """Return dataes chunker like [[date1, date2]]
+
+    Args:
+        date_from (datetime): from date
+        date_to (datetime): to date
+        default_delta (int, optional): date range. Defaults to 4.
+
+    Yields:
+        Generator: dates generator
+    """
+    dates_delta = (date_to - date_from).days
+    for count in range(0, dates_delta + 1, default_delta):
+        if count + default_delta > dates_delta:
+            default_delta = dates_delta - count + 1
+        yield [
+            date_from,
+            (date_from + timedelta(days=default_delta - 1)),
+        ]
+        date_from = date_from + timedelta(days=default_delta)
