@@ -1,11 +1,8 @@
-import requests
-import datetime
-
 from django.http import HttpResponseRedirect
 from rest_framework.views import APIView
 from rest_framework.viewsets import ModelViewSet
 from rest_framework.response import Response
-from rest_framework.exceptions import PermissionDenied, NotAcceptable
+from rest_framework.exceptions import PermissionDenied
 
 from .mixins import CredentialMixin
 from .pagination import LimitOffsetPaginationListAPIView
@@ -59,6 +56,7 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
     select_related_fields = ()  # must be tuple or list
     with_platforms_sample = False
     order_by_fields = ()  # must be tuple or list
+    filter_params = {}  # custom filter params
 
     def get_model(self):
         if not self.model:
@@ -75,17 +73,19 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
                 .filter(
                     integration_id=self.integration_id,
                     date__range=[self.date_from, self.date_to],
+                    **self.filter_params
                 )
             )
         else:
             qs = self.get_model().objects.filter(
                 integration_id=self.integration_id,
                 date__range=[self.date_from, self.date_to],
+                **self.filter_params
             )
         if self.with_platforms_sample:
             return qs.filter(platform_id=self.platform_id)
         if self.order_by_fields:
-            return qs.order_by(','.join(self.order_by_fields))
+            return qs.order_by(*self.order_by_fields)
         return qs
 
 
